from setuptools import setup, find_packages, Extension

setup(
    name='YooMoney_async',
    version='0.0.1',
    packages=find_packages(),
    url='https://github.com/Navigatoroleg/yoomoney_asunc',
    author='OlesMokovoz',
    author_email='oleg-oleg-2023@mail.ru',
    description='Unofficial YooMoney_async API python library'
)